@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.proc.c,v 3.70 1998/10/25 15:10:22 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.proc.c,v 3.77 2003/02/08 20:03:26 christos Exp $ */
 /*
  * sh.proc.c: Job manipulations
  */
@@ -14,11 +14,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -36,16 +32,16 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.proc.c,v 3.70 1998/10/25 15:10:22 christos Exp $")
+RCSID("$Id: sh.proc.c,v 3.77 2003/02/08 20:03:26 christos Exp $")
 
 #include "ed.h"
 #include "tc.h"
 #include "tc.wait.h"
 
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 #undef POSIX
 #define POSIX
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 #ifdef aiws
 # undef HZ
 # define HZ 16
@@ -211,7 +207,7 @@ loop:
     xprintf("Waiting...\n");
     flush();
 #endif /* JOBDEBUG */
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 # ifdef BSDJOBS
 #  ifdef BSDTIMES
 #   ifdef convex
@@ -288,13 +284,13 @@ loop:
     (void) sigset(SIGCHLD, pchild);
 #  endif /* !BSDSIGS */
 # endif /* !BSDJOBS */
-#else /* WINNT */
+#else /* WINNT_NATIVE */
     {
 	extern int insource;
 	pid = waitpid(-1, &w,
 	    (setintr && (intty || insource) ? WNOHANG | WUNTRACED : WNOHANG));
     }
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
 #ifdef JOBDEBUG
     xprintf("parent %d pid %d, retval %x termsig %x retcode %x\n",
@@ -320,13 +316,13 @@ loop:
     for (pp = proclist.p_next; pp != NULL; pp = pp->p_next)
 	if (pid == pp->p_procid)
 	    goto found;
-#if !defined(BSDJOBS) && !defined(WINNT)
+#if !defined(BSDJOBS) && !defined(WINNT_NATIVE)
     /* this should never have happened */
     stderror(ERR_SYNC, pid);
     xexit(0);
-#else /* BSDJOBS || WINNT */
+#else /* BSDJOBS || WINNT_NATIVE */
     goto loop;
-#endif /* !BSDJOBS && !WINNT */
+#endif /* !BSDJOBS && !WINNT_NATIVE */
 found:
     pp->p_flags &= ~(PRUNNING | PSTOPPED | PREPORTED);
     if (WIFSTOPPED(w)) {
@@ -803,6 +799,21 @@ static Char command[PMAXLEN + 4];
 static int cmdlen;
 static Char *cmdp;
 
+/* GrP
+ * unparse - Export padd() functionality 
+ */
+Char *
+unparse(t)
+    register struct command *t;
+{
+    cmdp = command;
+    cmdlen = 0;
+    padd(t);
+    *cmdp++ = '\0';
+    return Strsave(command);
+}
+
+
 /*
  * palloc - allocate a process structure and fill it up.
  *	an important assumption is made that the process is running.
@@ -1524,6 +1535,8 @@ dokill(v, c)
 {
     register int signum, len = 0;
     register char *name;
+    Char *sigptr;
+    char *ep;
     extern int T_Cols;
     extern int nsig;
 
@@ -1544,17 +1557,26 @@ dokill(v, c)
 	    xputchar('\n');
 	    return;
 	}
-	if (Isdigit(v[0][1])) {
-	    signum = atoi(short2str(v[0] + 1));
-	    if (signum < 0 || signum > (MAXSIG-1))
+ 	sigptr = &v[0][1];
+ 	if (v[0][1] == 's') {
+ 	    if (v[1]) {
+ 		v++;
+ 		sigptr = &v[0][0];
+ 	    } else {
+ 		stderror(ERR_NAME | ERR_TOOFEW);
+ 	    }
+ 	}
+ 	if (Isdigit(*sigptr)) {
+ 	    signum = strtol(short2str(sigptr), &ep, 10);
+	    if (signum < 0 || signum > (MAXSIG-1) || *ep)
 		stderror(ERR_NAME | ERR_BADSIG);
 	}
 	else {
 	    for (signum = 0; signum <= nsig; signum++)
 		if (mesg[signum].iname &&
-		    eq(&v[0][1], str2short(mesg[signum].iname)))
+ 		    eq(sigptr, str2short(mesg[signum].iname)))
 		    goto gotsig;
-	    setname(short2str(&v[0][1]));
+ 	    setname(short2str(sigptr));
 	    stderror(ERR_NAME | ERR_UNKSIG);
 	}
 gotsig:
@@ -1577,6 +1599,7 @@ pkill(v, signum)
     sigmask_t omask;
 #endif /* BSDSIGS */
     Char   *cp, **vp;
+    char   *ep;
 
 #ifdef BSDSIGS
     omask = sigmask(SIGCHLD);
@@ -1656,12 +1679,17 @@ pkill(v, signum)
 	else if (!(Isdigit(*cp) || *cp == '-'))
 	    stderror(ERR_NAME | ERR_JOBARGS);
 	else {
-#ifndef WINNT
-	    pid = atoi(short2str(cp));
+#ifndef WINNT_NATIVE
+	    pid = strtol(short2str(cp), &ep, 10);
 #else
-		pid = strtoul(short2str(cp),NULL,0);
-#endif /* WINNT */
-	    if (kill(pid, signum) < 0) {
+		pid = strtoul(short2str(cp),&ep,0);
+#endif /* WINNT_NATIVE */
+	    if (*ep) {
+		xprintf(CGETS(17, 14, "%S: Badly formed number\n"), cp);
+		err1++;
+		goto cont;
+	    }
+	    else if (kill(pid, signum) < 0) {
 		xprintf("%d: %s\n", pid, strerror(errno));
 		err1++;
 		goto cont;
@@ -1724,6 +1752,12 @@ pstart(pp, foregnd)
     if (!foregnd)
 	pclrcurr(pp);
     (void) pprint(pp, foregnd ? NAME | JOBDIR : NUMBER | NAME | AMPERSAND);
+
+    /* GrP run jobcmd hook if foregrounding */
+    if (foregnd) {
+	job_cmd(pp->p_command);
+    }
+
 #ifdef BSDJOBS
     if (foregnd) {
 	rv = tcsetpgrp(FSHTTY, pp->p_jobid);
@@ -1986,7 +2020,8 @@ pfork(t, wanttty)
 	if (t->t_dflg & F_NICE) {
 	    int nval = SIGN_EXTEND_CHAR(t->t_nice);
 #ifdef BSDNICE
-	    (void) setpriority(PRIO_PROCESS, 0, nval);
+	    if (setpriority(PRIO_PROCESS, 0, nval) == -1 && errno)
+		    stderror(ERR_SYSTEM, "setpriority", strerror(errno));
 #else /* !BSDNICE */
 	    (void) nice(nval);
 #endif /* !BSDNICE */
