@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tc.os.c,v 3.51 2000/07/04 19:46:23 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.os.c,v 3.54 2002/11/21 20:02:01 christos Exp $ */
 /*
  * tc.os.c: OS Dependent builtin functions
  */
@@ -14,11 +14,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -36,7 +32,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.os.c,v 3.51 2000/07/04 19:46:23 christos Exp $")
+RCSID("$Id: tc.os.c,v 3.54 2002/11/21 20:02:01 christos Exp $")
 
 #include "tw.h"
 #include "ed.h"
@@ -865,7 +861,7 @@ xmemmove(vdst, vsrc, len)
 #endif /* NEEDmemmove */
 
 
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 #ifdef tcgetpgrp
 int
 xtcgetpgrp(fd)
@@ -893,7 +889,7 @@ xtcsetpgrp(fd, pgrp)
 }
 
 #endif	/* tcgetpgrp */
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
 
 #ifdef YPBUGS
@@ -939,7 +935,7 @@ fix_strcoll_bug()
     static char *root = "/";
 
     if (!didfds)
-	fd = open(root, O_RDONLY);
+	fd = open(root, O_RDONLY|O_LARGEFILE);
 
     (void) strcoll(root, root);
 
@@ -1003,16 +999,16 @@ xstrerror(i)
 #endif /* strerror */
     
 #ifdef gethostname
-# if !defined(_MINIX) && !defined(__EMX__) && !defined(WINNT)
+# if !defined(_MINIX) && !defined(__EMX__) && !defined(WINNT_NATIVE)
 #  include <sys/utsname.h>
-# endif /* !_MINIX && !__EMX__ && !WINNT */
+# endif /* !_MINIX && !__EMX__ && !WINNT_NATIVE */
 
 int
 xgethostname(name, namlen)
     char   *name;
     int     namlen;
 {
-# if !defined(_MINIX) && !defined(__EMX__) && !defined(WINNT)
+# if !defined(_MINIX) && !defined(__EMX__) && !defined(WINNT_NATIVE)
     int     i, retval;
     struct utsname uts;
 
